@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-2001 by Solar Designer
  */
 
 #include <stdio.h>
@@ -28,24 +28,28 @@ void fmt_init(struct fmt_main *format)
 	}
 }
 
-int fmt_self_test(struct fmt_main *format)
+char *fmt_self_test(struct fmt_main *format)
 {
+	static char s_size[32];
 	struct fmt_tests *current;
 	char *ciphertext, *plaintext;
-	int size;
+	int index, max, size;
 	void *binary, *salt;
 
 	if (format->params.plaintext_length > PLAINTEXT_BUFFER_SIZE - 3)
-		return 1;
+		return "length";
 
-	if (format->methods.valid("*")) return 1;
+	if (format->methods.valid("*")) return "valid";
 
 	fmt_init(format);
 
-	if (!(current = format->params.tests)) return 0;
+	if (!(current = format->params.tests)) return NULL;
 
+	index = 0; max = format->params.max_keys_per_crypt;
+	if (max > 2 && !(format->params.flags & FMT_BS)) max = 2;
 	do {
-		if (format->methods.valid(current->ciphertext) != 1) break;
+		if (format->methods.valid(current->ciphertext) != 1)
+			return "valid";
 		ciphertext = format->methods.split(current->ciphertext, 0);
 		plaintext = current->plaintext;
 
@@ -53,30 +57,40 @@ int fmt_self_test(struct fmt_main *format)
 		salt = format->methods.salt(ciphertext);
 
 		if ((unsigned int)format->methods.salt_hash(salt) >=
-			SALT_HASH_SIZE) break;
+		    SALT_HASH_SIZE)
+			return "salt_hash";
 
 		format->methods.set_salt(salt);
-		format->methods.set_key(current->plaintext, 0);
+		format->methods.set_key(current->plaintext, index);
 
-		format->methods.crypt_all(1);
+		format->methods.crypt_all(index + 1);
 
 		for (size = 0; size < 3; size++)
-		if (format->methods.get_hash[size](0) !=
-			format->methods.binary_hash[size](binary)) break;
-		if (size < 3) break;
+		if (format->methods.get_hash[size](index) !=
+		    format->methods.binary_hash[size](binary)) {
+			sprintf(s_size, "get_hash[%d]", size);
+			return s_size;
+		}
 
-		if (!format->methods.cmp_all(binary, 1)) break;
-		if (!format->methods.cmp_one(binary, 0)) break;
-		if (!format->methods.cmp_exact(ciphertext, 0)) break;
+		if (!format->methods.cmp_all(binary, index + 1))
+			return "cmp_all";
+		if (!format->methods.cmp_one(binary, index))
+			return "cmp_one";
+		if (!format->methods.cmp_exact(ciphertext, index))
+			return "cmp_exact";
 
-		if (strncmp(format->methods.get_key(0), plaintext,
-			format->params.plaintext_length)) break;
+		if (strncmp(format->methods.get_key(index), plaintext,
+		    format->params.plaintext_length))
+			return "get_key";
+
+		index = (index << 1) + 1; /* 0, 1, 3, 7, 15, 31, 63, ... */
+		if (index >= max) index = 0;
 	} while ((++current)->ciphertext);
 
-	return current->ciphertext != NULL;
+	return NULL;
 }
 
-void fmt_default_init()
+void fmt_default_init(void)
 {
 }
 
@@ -110,6 +124,10 @@ int fmt_default_salt_hash(void *salt)
 	return 0;
 }
 
+void fmt_default_clear_keys(void)
+{
+}
+
 int fmt_default_get_hash(int index)
 {
 	return 0;
